@@ -117,5 +117,11 @@ class Client:
         request["token"] = self.client_token
         response = requests.post(f"{self.frontend_url}/client/projects/{self.project}/tasks/{task}/runs", json=request, params={"token": self.client_token})
         response_json = response.json()
-        run_id = response_json["runId"] # this may be null?
-        return run_id
\ No newline at end of file
+        if response.status_code == 201:
+            run_id = response_json["runId"]
+            return run_id
+        elif response.status_code == 404:
+            raise exceptions.CakeworkError("Task " + task + " for project " + self.project + " not found. Have you tried running `cakework deploy` first?")  
+        else:
+            print(response) # TODO delete? 
+            raise exceptions.CakeworkError("Internal server exception")  
\ No newline at end of file
